3.35.4 (2022-06-03)
===================
👷 Bug fixes
-----------

- pyramid: adapt TestApp.put_json method to CSRF

3.35.3 (2022-06-01)
===================
🎉 New features
--------------

- pkg: upgrade version of waitress to 2.1.1 or more, for security reason. (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/543)

👷 Bug fixes
-----------

- base64.decodestring is deprecated and has been removed
- pyramid: adapt TestApp.post_json method to CSRF
- pyramid: try to get "/login" if "/" is forbidden

3.35.2 (2022-03-31)
===================
👷 Bug fixes
-----------

- rql2sql: upgrade RQL version to fix translation of NOT EXISTS(X eid Y) (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/528)
- view: don't escape html tags inside image previews

3.35.1 (2022-03-09)
===================

- avoid excaping cubicweb:loadurl's value twice (to `#523 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/523>`_)
- don't escape whole key="value" attributes in TreeViewItemView (to `#523 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/523>`_)
- escape URLs passed as href attributes (to `#523 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/523>`_)

3.35 (2022-02-02)
=================
Breaking changes
----------------

- deprecate RQLSuggestionsBuilder component ; users of this component should
  now use `rqlsuggestions.RQLSuggestionsBuilder` instead. RQL bar completion
  behaviour can be changed by replacing the "rql_suggest" ajax function. If
  this function isn't registered, rql completion is disabled.
- remove RQLNoSuggestionsBuilder
- disable login using GET requests for security reasons
- web: remove support of old Internet Explorer versions: `add_css` no longer
  accepts `iespec` and `ieonly` arguments

🎉 New features
---------------

- add a Dockerfile in the skeleton
- add a function for deleting entities faster
- config: add help messages in configuration files (all-in-one and sources)
- disable constraints checks on the DB upon deletion
- show cube name when there is a version conflict
- skeleton: add release-new in skeleton
- upgrade to yams 0.47
- content negociation: we now can use `/<etype>/<rest_attr>` route for content
  negociation, if rest_attr is defined, the route `/<etype>/<rest_attr>` is
  disabled for content negociation in this situation

👷 Bug fixes
------------

- relation_type not existing in some conditions on RelationDefinition
  (ionDefinition.rtype has been deprecated in yams in favor of
  relation_type)

🤖 Continuous integration
-------------------------

- only collect warnings when running tests on the default branch (`#489 <https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/489>`_)
